The Classic Interface classes
==============================

The documentation for the C++ Fastjet covers all the classes in fastjet. The python classes of the classic interface behave exactly like they do in C++, therefore we are providing a link to the respective doxygen pages:

* `PseudoJet <http://fastjet.fr/repo/doxygen-3.4.1/classfastjet_1_1PseudoJet.html>`__
* `JetDefinition <http://fastjet.fr/repo/doxygen-3.4.1/classfastjet_1_1JetDefinition.html>`__
* `ClusterSequenceArea <http://fastjet.fr/repo/doxygen-3.4.1/classfastjet_1_1ClusterSequence.html>`__
* `AreaDefinition <http://fastjet.fr/repo/doxygen-3.4.1/classfastjet_1_1AreaDefinition.html>`__
* `Every Other C++ Class (Almost all available through the classic interface) <http://fastjet.fr/repo/doxygen-3.4.1/annotated.html>`__
